@@ -96,6 +96,7 @@ class Hermes:
 
     self.friends = {}
     self.blocked_pictures = []
+    self.callback.progress(0, 0)
     
     # -- Get a user session and retrieve Facebook friends...
     #
@@ -114,7 +115,6 @@ class Hermes:
           pass
         self.do_fb_login()
 
-      self.callback.progress(0, 0)
       # Get the list of friends...
       attrs = ['uid', 'name', 'pic_big', 'birthday_date']
       for friend in self.fb.users.getInfo(self.fb.friends.get(), attrs):
@@ -146,15 +146,20 @@ class Hermes:
     store = ContactStore(addresses)
     print "+++ Contact store created..."
     self.updated = []
+    self.unmatched = []
+    self.matched = []
     contacts = addresses.get_all_contacts()
+    contacts.sort(key=lambda obj: obj.get_name())
     current = 0
     maximum = len(contacts)
     for contact in contacts:
       current += 1
       self.callback.progress(current, maximum)
+      found = False
       for name in names.variants(contact.get_name()):
         if name in self.friends:
           friend = self.friends[name]
+          found = True
       
           if friend['pic'] and (resync or contact.get_property('photo') is None):
             print "Picture for %s is [%s]" % (name, friend['pic'])
@@ -164,7 +169,12 @@ class Hermes:
           if friend['birthday_date'] and (resync or contact.get_property('birth-date') is None):
             print "Birthday for %s is [%s]" % (name, friend['birthday_date'])
     
-          break  
+          break
+      
+      if found:
+        self.matched.append(contact)
+      else:
+        self.unmatched.append(contact)
 
     store.close()
 
